Handbook - Muscle System GLR Cells
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

MUSCLE SYSTEM GLR CELLS Click pictures for new window with figure and legend, click again for high resolution image
1 Overview Three pairs of GLR cells (GLRDL/R, GLRL/R, GLRVL/R) lie within the pseudocoelom at the level of the pharyngeal isthmus, slightly posterior to the nerve ring (GlrFIG 1). They are arranged in a sixfold symmetrical manner (GlrFIG 2). The cell bodies of the GLRs lie near the dorsal and ventral insertions of the muscle arms of the head, where the muscle arms enlarge to dive toward the isthmus of the pharynx. This close physical proximity may reflect the common lineage of the GLRs and the body wall muscles because both derive from the MS lineage. Their sister cells also include the head mesodermal cell, the pharyngeal musculature, and the coelomocytes (For more information see sections for: Head Mesomdermal Cell, Nonstriated Muscle, Coelomocytes). GlrFIG 1: Nuclei positions in the nerve ring. Based on Sulston et al., 1983. GlrFIG 2: GLR cells and their processes. A. Cell bodies of GLR cells are aligned dorsoventrally, just posterior to the nerve ring on each side of the pharynx isthmus. A thin, leaf-like process grows out of each cell to wrap the interior of the muscle-neuron plates of the nerve ring (inset). At the anterior edge of the nerve ring, this process narrows down to a thin rod that joins the labial process bundles and travels anteriorly to the level of the anterior end of the pharynx, where it peters out. B. Epifluorescent image from a transgenic animal expressing the gly-18::GFP reporter gene. The GLRL soma is seen on the lateral side of the isthmus. Anteriorly to the nerve ring region, the GLR process becomes quite thin and continues to travel along the lateral side of the pharynx, left lateral view. (Strain source: C.E. Warren, A. Krizus, and J.W. Dennis.) C. Epifluorescent image from a transgenic animal expressing the C05D9.1::GFP reporter gene, left lateral view. The anterior GLR processes flatten out at the nerve ring (NR) region. (Image source: R. Newbury. The Genome BC C. elegans gene expression consortium [McKay et al., 2004].) D. DIC image of the same animal as in C. Bar, 10 μm. All six GLR cell somata lie posteriorly to the nerve ring, and their positioning reflects the tilt of the nerve ring. The pronounced medial turn of each head muscle arm occurs in close apposition to GLR cell bodies. Anteriorly, each GLR cell extends a thin, sheet-like process (GlrFIG 2B). On the outside, these processes are surrounded by the muscle plate that lies inside the motor end plate layer of the nerve ring, where muscles receive synaptic input from the nerve ring motor neurons (GlrFIG 2 and GlrFIG 3). Each of these processes wraps around roughly one third of the circumference of the isthmus, touching its neighbor on each side (GlrFIG 4, GlrFIG 5 and GlrFIG 3H). There is no direct connection of the GLRs to the pharyngeal basement membrane, which lies between the GLR cells and the pharynx, and there is no basement membrane separating the muscle arms from the GLR processes (White et al., 1986). Arms from each of the eight longitudinal rows of the head muscles run along specific GLR cells such that each GLRDL/R and GLRVL/R is associated with muscle arms from a single row and each GLRL and GLRR is associated with muscle arms from two rows. Gap junctions exist between GLR cells and the muscle arms and between GLRs and RME motor neurons (see Gap Junctions). However, GLR cells do not make gap junctions to one another nor are they involved in any chemical synapses. GlrFIG 3A-D: Fine structure of the GLR cells. All except the top left inset are transverse-section TEMs. (NR) Nerve ring. (Top left inset) Section levels in A-F. Bars, 1 μm. A. Anteriorly to the nerve ring, the thin GLR processes join the labial process bundles. At the level shown, only GLRVL/R processes have joined the labial bundles (same area is magnified in top right inset), whereas GLRL/R and GLRDL/R process bundles are still seen closer to the pharynx. Some neuron cell bodies of the anterior ganglion are labeled. The GLR processes contact RME processes to make gap junctions in this region (not shown). (Image source: N2U [MRC] A17517-20.) B. Slightly posterior to the level in A, the muscle plate (muscle arm layer, green) is seen to be forming on the outside of the thin GLR processes, each of which occupies almost one-third the circumference of the isthmus. There is no BL between GLR cells and muscle arms. (Image source: N2U [MRC] A182 21-22.) C. More posteriorly, the muscle plate wraps around the whole circumference of the isthmus, outside the thin GLR processes. Outside the muscle plate, the nerve ring processes are seen. A basal lamina (not shown) separates the muscle plate from the nerve ring. (Image source: N2U [MRC] A191 4-7.) D. Posteriorly to the nerve ring, the first cell bodies that are seen are those of the dorsal pair of GLR cells. The muscle arms that turn inward to reach the muscle plate are in close contact with the cell bodies. (Image source: N2U [MRC] A195 9-12.) GlrFIG 3E-I: Fine structure of the GLR cells. All except H are transverse-section TEMs. (NR) Nerve ring. Bars, 1 μm. E. Because of the anterior tilt of the NR on the dorsal side, the cell bodies of the lateral and ventral GLR cells are placed more posteriorly than those of the dorsal pair. Seen at this level is the broad neck of each lateral and ventral GLR cell connecting the soma to the thin anterior process. (Image source: N2U [MRC] A201 1-4.) F. At the level of ASK and AVE cell bodies, the cell bodies of the lateral and ventral GLR cells are clustered on the ventral side. (Image source: N2U [MRC] A204 9-12.) G. Higher magnification of the section in F. Membrane-bound vacuoles are seen in GLRL and GLRVL cell bodies. H. GLR cells make extensive gap junctions (red bars) to the muscle arms and to RME neurons as shown. For stylistic reasons, RME processes are shown inside the GLR cell layer. In actuality, they lie outside the GLRs and muscle plate. There are also gap junctions between RME neurons and between the muscle bellies of the muscles. No gap junctions are seen between the muscle arms of cells within the same quadrant, but gap junctions exist between arms of cells in different quadrants. (Based on White et al., 1986.) I. In the anterior regions of the nerve ring where the muscle arm plate is not present anymore, the GLR cell processes make contacts with RME processes and make gap junctions (arrowheads) to them. (Image source: N2U [MRC] A178 10.) GlrFIG 4: Muscle arms of the head muscles. A. Diagram showing two stylized head muscle arms (dark green) approaching nerve ring. Muscle arms from the 32 muscles in the head and neck project onto the inside surface of the nerve ring in a highly ordered fashion. Their terminal branches lie between the processes of GLR cells (golden yellow) on the inside and the motor neurons of the nerve ring (dark red and purple) on the outside. Arms from the somatic head muscles run posteriorly until they reach the posterior nerve ring region. The arms from each muscle row then make an anterior arc of about 45° and extend inward to reach between the outside surface of the GLRs and the inner surface of the neural plate. This inward turn involves close apposition to the GLR cell bodies (see GlrFIG 3). In the neck, somatic muscles extend arms both to the nerve ring and to either the ventral or dorsal nerve cords where they receive additional synapses (not shown). (Light green) pharynx; (orange) basal lamina. B. Graphic rendition of the structure of the nerve ring and interior muscle plate. The muscle arms (dark green) innervated by RIML/R (purple) make four small spurs that may pierce through the basal lamina to access these neurons. Other motor neuron processes (only RME neurons are indicated) are located adjacent to the inner surface of the nerve ring, where they make NMJs with the muscle arms. Only a few cells on the right side are labeled. (Based on White et al., 1986.) GlrFIG 5: Color-coded TEM of muscle arms from posterior head muscles. Posterior head muscles reach the muscle plate at the level shown (insert). The arms turn inward near the GLRDR cell body (only the anterior edge of the soma is seen) and their terminal branches insinuate between the CEPsh and neuron processes to reach between the neuron layer and the inner GLR process layer. The muscle plate is separated from the neurons by a basal lamina (not shown). Only the right side structures are labeled. Bar, 1 μm. (Image source: N2U [MRC] A190-17.) Anterior to the nerve ring, GLR processes narrow down into thin processes and continue anteriorly to peter out at the level of the junction of the pharynx and the buccal cavity without any terminal specializations (GlrFIG 2 and GlrFIG 3). Throughout their length, the anterior GLR processes run in the inner labial bundles, closely apposed to the IL1 dendrites. The cytoplasm of the GLR cell body is electron dense and contains a distinctive collection of membrane-bound vacuoles. With TEM, these vacuoles formally look very similar to inclusions in the distal tip cells and the coelomocytes. This suggests an active endocytic or secretory function for GLRs. 2 Function of GLR Cells Because of their location, connectivity pattern, and lineage, GLR cells are suggested to be mesodermal scaffolding cells that guide muscle arms to appropriate territories during development (White et al., 1986). The C. elegans myoD homolog hlh-1, which is expressed by lineal precursors of body wall muscle and is required for normal muscle function, is also expressed in GLR cells in late embryogenesis and larval stages. It has been suggested that hlh-1 might drive expression of cell-surface proteins that mediate recognition and contact between GLRs and head muscles (Krause et al., 1994). Similar to body wall muscle cells, GLR cells secrete type IV collagen, which is integrated into the basement membrane underlying the muscle (Graham et al., 1997; Norman and Moerman, 2000). At the anterior end of the nerve ring, the sheet-like anterior processes of GLRs briefly seal the space between the end of the somatic basement membrane of the muscle and the basement membrane of the pharynx and the pseudocoelom. Hence, anterior to this region, the narrow space between the pharynx and outer tissues is designated as an accessory pseudocoelom (see Pericellular Structures) (Z. Altun and D.H. Hall, unpubl.). It is not yet clear if there is material exchange between these two spaces. When any one of the parental cells of the GLRs (MSaaaaaa for GLRDL/R; MSapaaaa for GRLL/VL; MSppaaaa for GLRR/VR) is killed in the embryo, the worms hatch late and arrest as starved L1-stage animals. In these animals, nerve rings are displaced anteriorly and there is widespread degeneration and vacuolation in neurons and hypodermis, which may result from disruption of the GLR seal (A. Chisholm, pers. comm.). 3 List of GLR Cells GLRL; MSapaaaad GLRR; MSppaaaad GLRVL; MSapaaaav GLRVR; MSppaaaav GLRDL; MSaaaaaal GLRDR; MSaaaaaar
4 References Graham, P.L., Johnson, J.J., Wang, S., Sibley, M.H., Gupta, M.C. and Kramer, J.M. 1997. Type IV collagen is detectable in most, but not all, basement membranes of Caenorhabditis elegans and assembles on tissues that do not express it. J. Cell Biol. 137: 1171-1183. Article Krause, M., White Harrison, S., Xu, S-Q., Chen, L. and Fire, A. 1994. Elements regulating cell- and stage-specific expression of the C. elegans MyoD family homolog hlh-1. Dev. Biol. 166: 133-148. Abstract McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynski, B., Ha, E., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah, A., Marra, M., McGhee, J., Newbury, R., Pouzyrev, R., Riddle, D.L., Sonnhammer, E., Tian, H., Tu, D., Tyson, J.R., Vatcher, G., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quantit. Biol. 68: 159-69. Abstract Norman, K.R. and Moerman, D.G. 2000. The let-268 locus of Caenorhabditis elegans encodes a procollagen lysyl hydroxylase that is essential for type IV collagen secretion. Dev. Biol. 227: 690-705. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev. Biol. 100: 64-119. Article White, J.G., Southgate, E., Thomson, J.N. and Brenner, S. 1986. The structure of the nervous system of the nematode Caenorhabditis elegans. Phil. Trans. Roy. Soc. Lond. 314B: 1-340. Article This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Muscle system, GLR cells. In WormAtlas. doi:10.3908/wormatlas.1.9 Edited for the web by Laura A. Herndon. Last revision: April 23, 2013

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |